<template>
  <div class="inner">
    <a-row type="flex" justify="space-between" style="margin-bottom: 20px">
      <a-col :span="4">
        <a-button  type="primary" @click="editData('add',{})">添加</a-button>
      </a-col>
    </a-row>
    <div class="table-cont">
      <a-table :columns="columns" :data-source="tableData" :pagination="pagination" :rowKey="record=>record.id" bordered>
        <template #action="action,row">
          <a-button type="link" @click="editData('edit',row)">编辑</a-button>
          <a-button type="link" class="delBtn" @click="delData(row)">删除</a-button>
        </template>
      </a-table>
    </div>
    <same-level-mod-group ref="sameLevelMod" @refresh="getUserList"></same-level-mod-group>
  </div>
</template>

<script>
import sameLevelModGroup from "@/views/Admin/components/sameLevelGroupMod.vue"
import {getUserInfo} from "@/util/storage";
import {delSameLevelGroup, getSameLevelGroup} from "@/api/user";
export default {
  name: 'sameLevel',
  components: {
    sameLevelModGroup
  },
  data () {
    return {
      areaVal: [],
      unittype: null,
      districtId: null,
      search:{
        pageIndex: 1,
        pageSize: 10,
      },
      columns:[
        {
          title: '分组名称',
          dataIndex: 'name',
          key: 'name',
          align: 'center'
        },
        {
          title: '操作',
          width: '12%',
          key: 'action',
          scopedSlots: { customRender: 'action' }
        },
      ],
      tableData: [],
      pagination: {
        current: 1,
        defaultCurrent: 1,
        defaultPageSize: 10,
        total: 0,
        onChange: ( page, pageSize ) => this.onPageChange(page,pageSize),
        showTotal: total => `共 ${total} 条`
      },
      fieldNames:{
        label: 'name',
        value: 'id',
        children: 'children'
      }
    }
  },
  created() {
    const t = this
    t.unittype = getUserInfo().unittype
    t.districtId = getUserInfo().districtId
    t.getUserList()
  },
  methods:{
    async getUserList(){
      const t = this
      const res = await getSameLevelGroup(t.search);
      if(res.data.code == 100){
        t.tableData = res.data.data
        t.pagination.total = res.data.total
      }else{
        t.$message.warning(res.data.msg);
      }
    },

    resetSearch(){
      const t = this
      t.areaVal = []
      t.search = {
        pageIndex: 1,
        pageSize: 10,
      }
      t.getUserList()
    },

    editData(type,data){
      const t = this
      t.$refs.sameLevelMod.openDialog(type,data)
    },

    async delData(row){
      const t = this
      this.$confirm({
        title: '提示',
        content: h => <div>是否删除该条信息？</div>,
        cancelText: '取消',
        okText: '确认',
        centered: true,
        onOk() {
          delSameLevelGroup(row.id).then(res=>{
            if(res.data.code == 100){
              t.$message.success('删除成功');
              t.getUserList()
            }else{
              t.$message.warning(res.data.msg);
            }
          })
        },
        onCancel() {
          console.log('Cancel');
        },
      });
    },
    onPageChange(page, pageSize) {
      const t= this
      t.pagination.current = page
      t.search.pageIndex = page
      t.getUserList()
    },
  }
}
</script>

<style lang="less" scoped>
.delBtn{
  color: @danger
}
</style>
